@@ -25,7 +25,7 @@
  * 
  * You should have received a copy of the GNU General Public License along with
  * GNU Smalltalk; see the file COPYING.  If not, write to the Free Software
- * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
+ * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  *
  ***********************************************************************/
 
@@ -39,16 +39,14 @@
 #include <stdlib.h>
 #endif
 
-#ifdef atarist
-long _stksize = -1L;		/* what does this do? */
-#endif
-
 int
 main(int argc, char **argv)
 {
+  int result;
   gst_smalltalk_args(argc, argv);
-  gst_init_smalltalk();
-  gst_top_level_loop();
+  result = gst_init_smalltalk();
+  if (result == 0)
+    gst_top_level_loop();
 
-  exit(0);
+  exit(result <= 0 ? 0 : result);
 }
