@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * As a special exception to the GNU General Public License, if you
  * distribute this file as part of a program that also links with and
@@ -673,7 +673,7 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
 
           case PA_DOUBLE|PA_FLAG_LONG_DOUBLE:
 #ifdef HAVE_LONG_DOUBLE
-           args[index].pa_long_double = **(const snv_long_double **)(ap + index);
+           args[index].pa_long_double = **(const long double **)(ap + index);
             break;
 #endif
            /* else fall through */
@@ -854,7 +854,7 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
             break;
 
           case PA_DOUBLE|PA_FLAG_LONG_DOUBLE:
-	    args[index].pa_long_double = va_arg (ap, snv_long_double);
+	    args[index].pa_long_double = va_arg (ap, long double);
             break;
 
           case PA_DOUBLE:
